@@ -4,7 +4,7 @@ use WWW::Mechanize::Firefox;
 use Carp qw(croak);
 
 use vars qw($VERSION);
-$VERSION = '0.34';
+$VERSION = '0.35';
 
 =head1 NAME
 
@@ -21,6 +21,13 @@ WWW::Mechanize::Firefox::DSL - Domain Specific Language for short scripts
     
     click($links[0]);
 
+This module exports all methods of one WWW::Mechanize::Firefox
+object as subroutines. That way, you can write short scripts without
+cluttering every line with C<< $mech-> >>.
+
+This module is highly experimental and might vanish from the distribution
+again if I find that it is useless.
+
 =cut
 
 sub import {
@@ -63,4 +70,18 @@ sub import {
     }
 }
 
-1;
\ No newline at end of file
+1;
+
+=head1 AUTHORS
+
+Max Maischein C<corion@cpan.org> and Zsban Ambrus
+
+=head1 COPYRIGHT (c)
+
+Copyright 2009-2010 by Max Maischein C<corion@cpan.org>.
+
+=head1 LICENSE
+
+This module is released under the same terms as Perl itself.
+
+=cut
